searchData={"items":[{"type":"module","title":"CodestatsAPI","doc":"This module is responsible for handling the requests to the Code::Stats API.","ref":"CodestatsAPI.html"},{"type":"function","title":"CodestatsAPI.get_user_data/1","doc":"Returns the user's data from the Code::Stats API.","ref":"CodestatsAPI.html#get_user_data/1"},{"type":"function","title":"Examples - CodestatsAPI.get_user_data/1","doc":"iex> {:ok, %CodestatsAPI.Stats{} = result} = CodestatsAPI.get_user_data(\"cbic\")\n    iex> result.user\n    \"cbic\"","ref":"CodestatsAPI.html#get_user_data/1-examples"},{"type":"module","title":"CodestatsAPI.Stats","doc":"Structure containing all the user's stats.","ref":"CodestatsAPI.Stats.html"},{"type":"function","title":"CodestatsAPI.Stats.parse/1","doc":"Parses the user's data from the Code::Stats API.","ref":"CodestatsAPI.Stats.html#parse/1"},{"type":"type","title":"CodestatsAPI.Stats.t/0","doc":"","ref":"CodestatsAPI.Stats.html#t:t/0"},{"type":"module","title":"CodestatsAPI.Stats.Dates","doc":"This map describes the amount of XP earned on each date.\n\nDate in format `YYYY-MM-DD` is used as a key, and the amount of XP earned on that date is used as a value.","ref":"CodestatsAPI.Stats.Dates.html"},{"type":"function","title":"CodestatsAPI.Stats.Dates.parse/1","doc":"Parses the dates from the user's data from the Code::Stats API.","ref":"CodestatsAPI.Stats.Dates.html#parse/1"},{"type":"type","title":"CodestatsAPI.Stats.Dates.t/0","doc":"","ref":"CodestatsAPI.Stats.Dates.html#t:t/0"},{"type":"module","title":"CodestatsAPI.Stats.Languages","doc":"Map of programming lanuage names to XP.\n\nExample:\n  %{\n    \"Elixir\": %{\n      new_xps: 100,\n      xps: 464413\n    },\n    \"Rust\": %{\n      new_xps: 0,\n      xps: 500\n    }\n  }","ref":"CodestatsAPI.Stats.Languages.html"},{"type":"function","title":"CodestatsAPI.Stats.Languages.parse/1","doc":"Parses the languages from the user's data from the Code::Stats API.","ref":"CodestatsAPI.Stats.Languages.html#parse/1"},{"type":"type","title":"CodestatsAPI.Stats.Languages.t/0","doc":"","ref":"CodestatsAPI.Stats.Languages.html#t:t/0"},{"type":"module","title":"CodestatsAPI.Stats.Machines","doc":"Map of machine names to XP.\n\nExample:\n  %{\n    \"MacBook Pro (20-inch, 2030)\": %{\n      new_xps: 100,\n      xps: 464413\n    },\n    \"Lenovo yoba\": %{\n      new_xps: 0,\n      xps: 500\n    }\n  }","ref":"CodestatsAPI.Stats.Machines.html"},{"type":"function","title":"CodestatsAPI.Stats.Machines.parse/1","doc":"Parses the machines from the user's data from the Code::Stats API.","ref":"CodestatsAPI.Stats.Machines.html#parse/1"},{"type":"type","title":"CodestatsAPI.Stats.Machines.t/0","doc":"","ref":"CodestatsAPI.Stats.Machines.html#t:t/0"},{"type":"module","title":"CodestatsAPI.Stats.Xp","doc":"Integer representing the amount of XP.","ref":"CodestatsAPI.Stats.Xp.html"},{"type":"function","title":"CodestatsAPI.Stats.Xp.parse/1","doc":"Parses the XP from the user's data from the Code::Stats API.","ref":"CodestatsAPI.Stats.Xp.html#parse/1"},{"type":"type","title":"CodestatsAPI.Stats.Xp.t/0","doc":"","ref":"CodestatsAPI.Stats.Xp.html#t:t/0"},{"type":"extras","title":"CodestatsAPI","doc":"# CodestatsAPI\n\n![Build and tests workflow](https://github.com/general-CbIC/codestats_api/actions/workflows/ci-tests.yml/badge.svg)\n[![hex.pm version](https://img.shields.io/hexpm/v/codestats_api.svg?style=flat)](https://hex.pm/packages/codestats_api)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg?style=flat)](https://hexdocs.pm/codestats_api/)\n[![License](https://img.shields.io/hexpm/l/codestats_api.svg?style=flat)](https://github.com/general-CbIC/codestats_api/blob/main/LICENSE)\n[![Total Download](https://img.shields.io/hexpm/dt/codestats_api.svg?style=flat)](https://hex.pm/packages/codestats_api)\n\nElixir library for making requests to [Code::Stats](https://codestats.net/). Why not?","ref":"readme.html"},{"type":"extras","title":"Requirements table - CodestatsAPI","doc":"| CodestatsAPI | Elixir  | Erlang |\n|--------------|---------|--------|\n| <= 0.2.0     | >= 1.10 | >= 23  |\n| >= 0.3.0     | >= 1.18 | >= 25  |","ref":"readme.html#requirements-table"},{"type":"extras","title":"Installation - CodestatsAPI","doc":"Add `:codestats_api` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:codestats_api, \"~> 0.3.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - CodestatsAPI","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Get user's Stats - CodestatsAPI","doc":"```elixir\n{:ok, %CodestatsAPI.Stats{}} = CodestatsAPI.get_user_data(\"username\")\n```\n\nThat's all :)\nA detailed description of the `Stats` structure can be found [here](https://hexdocs.pm/codestats_api/CodestatsAPI.Stats.html).","ref":"readme.html#get-user-s-stats"},{"type":"extras","title":"Contributions - CodestatsAPI","doc":"If you feel something can be improved or have any questions about specific behaviors or pieces of implementation, please feel free to file an issue. Proposed changes should be taken to issues before any PRs to save time on code that might not be merged upstream.\n\nIf you are ready to change the project, please read the [Contributing guide](CONTRIBUTING.md) first.","ref":"readme.html#contributions"},{"type":"extras","title":"1.0.0 Roadmap - CodestatsAPI","doc":"- [x] Interface to get user's stats\n- [ ] Interface to push updates","ref":"readme.html#1-0-0-roadmap"},{"type":"extras","title":"Contributing to CodestatsAPI","doc":"# Contributing to CodestatsAPI\n\nCodestatsAPI is written in [Elixir](https://elixir-lang.org/).\n\nFor branching management, this project uses [git-flow](https://github.com/petervanderdoes/gitflow-avh). The `main` branch is reserved for releases: the development process occurs on the `develop` and `feature` branches. Please never commit to `main`.\n\nYou can use [asdf](https://asdf-vm.com/) to set up the required Elixir and OTP. Current versions are listed in the `.tool-versions` file.","ref":"contributing.html"},{"type":"extras","title":"Setup - Contributing to CodestatsAPI","doc":"","ref":"contributing.html#setup"},{"type":"extras","title":"Local repository - Contributing to CodestatsAPI","doc":"1. Fork the repository.\n2. Clone your fork to a local repository:\n\n    ```shell\n    git clone https://github.com/your-login/codestats_api.git\n    cd codestats_api\n    ```\n\n3. Checkout `develop`:\n\n    ```shell\n    git checkout develop\n    ```","ref":"contributing.html#local-repository"},{"type":"extras","title":"Development environment (using asdf) - Contributing to CodestatsAPI","doc":"1. Install asdf by [Getting Started guideline](https://asdf-vm.com/guide/getting-started.html)\n2. Add plugins for elixir and OTP\n\n    ```shell\n    asdf plugin-add elixir https://github.com/asdf-vm/asdf-elixir.git\n    asdf plugin add erlang https://github.com/asdf-vm/asdf-erlang.git\n    ```\n\n3. Install tools:\n\n    ```shell\n    cd codestats_api\n    asdf install\n    ```","ref":"contributing.html#development-environment-using-asdf"},{"type":"extras","title":"Development environment (without asdf) - Contributing to CodestatsAPI","doc":"Please see [installation instructions](https://elixir-lang.org/install.html).","ref":"contributing.html#development-environment-without-asdf"},{"type":"extras","title":"Git-flow - Contributing to CodestatsAPI","doc":"If you want to use the `git-flow` CLI, please check [installation instructions](https://github.com/petervanderdoes/gitflow-avh/wiki/Installation).","ref":"contributing.html#git-flow"},{"type":"extras","title":"Building the project - Contributing to CodestatsAPI","doc":"1. Fetch the project dependencies:\n\n    ```shell\n    cd codestats_api\n    mix deps.get\n    ```\n\n2. Run the static analyzers:\n\n    ```shell\n    mix check\n    ```","ref":"contributing.html#building-the-project"},{"type":"extras","title":"Workflow - Contributing to CodestatsAPI","doc":"To make a change, please use this workflow:\n\n1. Checkout `develop` and apply the last upstream changes (use rebase, not merge!):\n\n    ```shell\n    git checkout develop\n    git fetch --all --prune\n    git rebase upstream/develop\n    ```\n\n2. For a tiny patch, create a new branch with an explicit name:\n\n    ```shell\n    git checkout -b  \n    ```\n\n    Alternatively, if you are working on a feature that would need more work, you can create a feature branch with `git-flow`:\n\n    ```shell\n    git flow feature start  \n    ```\n\n    *Note: always open an issue and ask before starting a big feature, to avoid it not being merged and your time lost.*\n\n3. When your feature is ready, feel free to use [interactive rebase](https://help.github.com/articles/about-git-rebase/) so your history looks clean and easy to follow. Then, apply the last upstream changes on `develop` to prepare integration:\n\n    ```shell\n    git checkout develop\n    git fetch --all --prune\n    git rebase upstream/develop\n    ```\n\n4. If there were commits on `develop` since the beginning of your feature branch, integrate them by **rebasing** if your branch has few commits, or merging if you had a long-lived branch:\n\n    ```shell\n    git checkout  \n    git rebase develop\n    ```\n\n    *Note: the only case you should merge is when you are working on a big feature. If it is the case, we should have discussed this before as stated above.*\n\n5. Run the tests and static analyzers to ensure there is no regression and all works as expected:\n\n    ```shell\n    mix check\n    ```\n\n6. If it’s all good, open a pull request to merge your branch into the `develop` branch on the main repository.","ref":"contributing.html#workflow"},{"type":"extras","title":"Coding style - Contributing to CodestatsAPI","doc":"Please format your code with `mix format` or your editor and follow\n[this style guide](https://github.com/christopheradams/elixir_style_guide).\n\nAll contributed code must be documented and functions must have typespecs. In general, take your inspiration from the existing code.","ref":"contributing.html#coding-style"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}